==> jettable1.0.0.zip: jettable/sample/client_javadoc.php <==
<?php
require_once "../TableUtility.php";

$list = array();


$list[] = array("sign"=>"boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">booleanValue()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ֥Ȥͤץߥƥ boolean Ȥ֤ޤ");
$list[] = array("sign"=>"boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">equals(Object obj)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; null ǤϤʤΥ֥ȤƱ boolean ͤɽ Boolean ֥Ȥξˤtrue ֤ޤ");
$list[] = array("sign"=>"static boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">getBoolean(String name)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ˤäƻꤵ줿ƥץѥƥ¸ߤ줬ʸ \"true\" ˤtrue ֤ޤ");
$list[] = array("sign"=>"int", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">hashCode()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ֥ȤΥϥå女ɤ֤ޤ");
$list[] = array("sign"=>"String", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">toString()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ͤɽ String ֥Ȥ֤ޤ");
$list[] = array("sign"=>"static Boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">valueOf(String s)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ꤵ줿 String ɽͤ Boolean ֤ޤ");



$table = new Table();
$table->setData($list);

$table->setHeader(array(
	"sign"=>"᥽åɤγ", 
	"summary"=>"", 
));

$table->appendAttribute("border", "1");
$table->appendAttribute("cellpadding", "3");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");

$table->margeHeaderColumn("sign", 2);

$table->appendAttributeHeaderRow("bgcolor", "CCCCFF");
$table->appendAttributeHeaderColumn("sign", "align", "left");
$table->appendAttributeHeaderColumn("sign", "style", "font-size:1.5em;");

$table->appendAttributeColumn("sign", "style", "font-size:0.7em;");
$table->appendAttributeColumn("sign", "align", "right");
$table->appendAttributeColumn("sign", "valign", "top");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>

==> jettable2.0.0.zip: jettable/sample/client_javadoc.php <==
<?php
require_once "../JetTable.php";

$list = array();


$list[] = array("sign"=>"boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">booleanValue()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ֥Ȥͤץߥƥ boolean Ȥ֤ޤ");
$list[] = array("sign"=>"boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">equals(Object obj)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; null ǤϤʤΥ֥ȤƱ boolean ͤɽ Boolean ֥Ȥξˤtrue ֤ޤ");
$list[] = array("sign"=>"static boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">getBoolean(String name)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ˤäƻꤵ줿ƥץѥƥ¸ߤ줬ʸ \"true\" ˤtrue ֤ޤ");
$list[] = array("sign"=>"int", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">hashCode()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ֥ȤΥϥå女ɤ֤ޤ");
$list[] = array("sign"=>"String", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">toString()</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp; Boolean ͤɽ String ֥Ȥ֤ޤ");
$list[] = array("sign"=>"static Boolean", "summary"=>"<code><span style=\"color:#00f;text-decoration:underline;font-weight:bold;\">valueOf(String s)</span></code><br>&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;ꤵ줿 String ɽͤ Boolean ֤ޤ");



$table = new JetTable();
$table->setData($list);

$table->setHeader(array(
	"sign"=>"᥽åɤγ", 
	"summary"=>"", 
));

$table->appendAttribute("border", "1");
$table->appendAttribute("cellpadding", "3");
$table->appendAttribute("cellspacing", "0");
$table->appendAttribute("width", "100%");

$table->margeHeaderColumn("sign", 2);

$table->appendAttributeHeaderRow("bgcolor", "CCCCFF");
$table->appendAttributeHeaderColumn("sign", "align", "left");
$table->appendAttributeHeaderColumn("sign", "style", "font-size:1.5em;");

$table->appendAttributeColumn("sign", "style", "font-size:0.7em;");
$table->appendAttributeColumn("sign", "align", "right");
$table->appendAttributeColumn("sign", "valign", "top");

print<<<HEADER
<html>
<head>
<style type="text/css">
<!--
-->
</style>
</head>
<body>
HEADER;

print $table->getTableHtml();

print<<<FOOTER
</body>
</html>
FOOTER;
?>
